pub struct RwLockReadGuard<'a, R, T>where
R: RawMutex,
T: ?Sized,{ /* private fields */ }Expand description
Async read lock guard.
Owning an instance of this type indicates having successfully locked the read-write lock for reading, and grants access to the contents.
Dropping it unlocks the read-write lock.